
/* Chrysalide - Outil d'analyse de fichiers binaires
 * instance.h - prototypes pour le partage de données d'architecture quelconques
 *
 * Copyright (C) 2016-2017 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef _ARCH_SHARING_INSTANCE_H
#define _ARCH_SHARING_INSTANCE_H


#include <stdbool.h>
#include <glib-object.h>



#define G_TYPE_SHARED_INSTANCE               (g_shared_instance_get_type())
#define G_SHARED_INSTANCE(obj)               (G_TYPE_CHECK_INSTANCE_CAST((obj), G_TYPE_SHARED_INSTANCE, GSharedInstance))
#define G_SHARED_INSTANCE_CLASS(vtable)      (G_TYPE_CHECK_CLASS_CAST((vtable), G_TYPE_SHARED_INSTANCE, GSharedInstanceIface))
#define GTK_IS_SHARED_INSTANCE(obj)          (G_TYPE_CHECK_INSTANCE_TYPE((obj), G_TYPE_SHARED_INSTANCE))
#define GTK_IS_SHARED_INSTANCE_CLASS(vtable) (G_TYPE_CHECK_CLASS_TYPE((vtable), G_TYPE_SHARED_INSTANCE))
#define G_SHARED_INSTANCE_GET_IFACE(inst)    (G_TYPE_INSTANCE_GET_INTERFACE((inst), G_TYPE_SHARED_INSTANCE, GSharedInstanceIface))


/* Règles de partage d'une instance GObject (coquille vide) */
typedef struct _GSharedInstance GSharedInstance;

/* Règles de partage d'une instance GObject (interface) */
typedef struct _GSharedInstanceIface GSharedInstanceIface;


/* Détermine le type d'une interface pour le partage d'instance. */
GType g_shared_instance_get_type(void) G_GNUC_CONST;

/* Initialise un nouvel objet partagé avec des informations. */
bool g_shared_instance_apply_template(GSharedInstance *, const GSharedInstance *);

/* Réalise une copie minimale d'un contenu partagé. */
void g_shared_instance_define_template(const GSharedInstance *, GSharedInstance *);

/* Incrémente le compteur de références d'un élément partagé. */
void g_shared_instance_ref(GSharedInstance *);

/* Décrémente le compteur de références d'un élément partagé. */
void g_shared_instance_unref(GSharedInstance *);

/* Fournit la valeur du compteur de partage. */
unsigned int g_shared_instance_get_references(const GSharedInstance *);

/* Incrémente le compteur de partage. */
void g_shared_instance_inc_references(GSharedInstance *);

/* Décrémente le compteur de partage. */
void g_shared_instance_dec_references(GSharedInstance *);

/* Compare de façon accélérée un object partagé avec un autre. */
int g_shared_instance_compare(const GSharedInstance * const *, const GSharedInstance * const *);



#endif  /* _ARCH_SHARING_INSTANCE_H */
